@@ -348,7 +348,7 @@ fn print_registers<T: Write>(f: &mut T, ctx: &MinidumpContext) -> io::Result<()>
     for reg in ctx.general_purpose_registers() {
         if registers.contains(reg) {
             let reg_val = ctx.format_register(reg);
-            let next = format!(" {: >5} = {}", reg, reg_val);
+            let next = format!(" {: >6} = {}", reg, reg_val);
             if output.chars().count() + next.chars().count() > 80 {
                 // Flush the buffer.
                 writeln!(f, " {}", output)?;
@@ -926,10 +926,10 @@ Unknown streams encountered:
     // Convert an integer to a hex string, with leading 0's for uniform width.
     fn json_hex(&self, val: u64) -> String {
         match self.system_info.cpu {
-            Cpu::X86 | Cpu::Ppc | Cpu::Sparc | Cpu::Arm => {
+            Cpu::X86 | Cpu::Ppc | Cpu::Sparc | Cpu::Arm | Cpu::Mips => {
                 format!("0x{:08x}", val)
             }
-            Cpu::X86_64 | Cpu::Ppc64 | Cpu::Arm64 | Cpu::Unknown(_) => {
+            _ => {
                 format!("0x{:016x}", val)
             }
         }
